==> qt-creator-opensource-src-4.4.0.zip: qt-creator-opensource-src-4.4.0/tests/unit/unittest/dummyclangipcclient.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include <clangcodemodelclientinterface.h>

class DummyIpcClient: public ClangBackEnd::ClangCodeModelClientInterface
{
public:
    void dispatch(const ClangBackEnd::MessageEnvelop &) override {}

    void alive() override {}
    void echo(const ClangBackEnd::EchoMessage &) override {}
    void codeCompleted(const ClangBackEnd::CodeCompletedMessage &) override {}
    void translationUnitDoesNotExist(const ClangBackEnd::TranslationUnitDoesNotExistMessage &) override {}
    void projectPartsDoNotExist(const ClangBackEnd::ProjectPartsDoNotExistMessage &) override {}
    void documentAnnotationsChanged(const ClangBackEnd::DocumentAnnotationsChangedMessage &) override {}
    void references(const ClangBackEnd::ReferencesMessage &) override {}
};

==> qt-creator-opensource-src-4.6.1.zip: qt-creator-opensource-src-4.6.1/tests/unit/unittest/dummyclangipcclient.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include <clangcodemodelclientinterface.h>

class DummyIpcClient: public ClangBackEnd::ClangCodeModelClientInterface
{
public:
    void dispatch(const ClangBackEnd::MessageEnvelop &) override {}

    void alive() override {}
    void echo(const ClangBackEnd::EchoMessage &) override {}
    void codeCompleted(const ClangBackEnd::CodeCompletedMessage &) override {}
    void documentAnnotationsChanged(const ClangBackEnd::DocumentAnnotationsChangedMessage &) override {}
    void references(const ClangBackEnd::ReferencesMessage &) override {}
    void followSymbol(const ClangBackEnd::FollowSymbolMessage &) override {}
    void tooltip(const ClangBackEnd::ToolTipMessage &) override {}
};
